@@ -29,16 +29,10 @@
  * See the ChangeLog files for a list of changes. 
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-help.h>
 #include <libgnomeui/gnome-file-entry.h>
 #include <gconf/gconf-client.h>
-#include <eel/eel-vfs-extensions.h>
 
 #include <unistd.h> /* getpid and unlink */
 #include <stdlib.h> /* rand   */
@@ -53,14 +47,15 @@
 #include <gedit-utils.h>
 #include <gedit-debug.h>
 #include <gedit-file.h>
+#include <dialogs/gedit-dialogs.h>
 
-#define DIFF_BASE_KEY 		"/apps/gedit-2/plugins/diff"
+#define DIFF_BASE_KEY 		"/apps/gedit2/plugins/diff"
 #define DIFF_LOCATION_KEY	"/diff-program-location"
 #define UNIFIED_FORMAT_KEY	"/use-unified-format"
 #define IGNORE_BLANKS		"/ignore-blanks"
 
-#define MENU_ITEM_LABEL		N_("Co_mpare Files...")
-#define MENU_ITEM_PATH		"/menu/File/FileOps_2/"
+#define MENU_ITEM_LABEL		N_("_Compare files...")
+#define MENU_ITEM_PATH		"/menu/File/FileOps/"
 #define MENU_ITEM_NAME		"Diff"	
 #define MENU_ITEM_TIP		N_("Makes a diff file from two documents or files")
 
@@ -421,8 +416,6 @@ diff_real (void)
 
 	do 
 	{
-		GError *error = NULL;
-		
 		ret = gtk_dialog_run (GTK_DIALOG (dialog->dialog));
 
 		switch (ret) {
@@ -434,16 +427,7 @@ diff_real (void)
 				break;
 
 			case GTK_RESPONSE_HELP:
-				/* FIXME: choose a better link id */
-				gnome_help_display ("gedit.xml", "gedit-use-plugins", &error);
-	
-				if (error != NULL)
-				{
-					g_warning (error->message);
-
-					g_error_free (error);
-				}
-
+				
 				break;
 
 			default:
@@ -532,7 +516,6 @@ diff_execute (DiffDialog *dialog)
 
 	if (!state_1)
 	{
-		gchar *uri;
 		gchar *sn;
 		
 		if (file_name_1 != NULL)
@@ -552,23 +535,17 @@ diff_execute (DiffDialog *dialog)
 		file_name_1 = temp_file_name_new (sn);
 		gedit_debug (DEBUG_PLUGINS, "file_name_1: %s", file_name_1);
 		g_free (sn);
-		
-		uri = eel_make_uri_canonical (file_name_1);
-		g_return_val_if_fail (uri != NULL, FALSE);
-		
-		if (!gedit_document_save_a_copy_as (document, uri, NULL))
+
+		if (!gedit_document_save_a_copy_as (document, file_name_1, NULL))
 		{
 			g_free (file_name_1);
 			file_name_1 = NULL;
 		}
-
-		g_free (uri);
 	}
 
 	if (!state_2)
 	{
 		gchar *sn;
-		gchar *uri;
 
 		if (file_name_2 != NULL)
 			g_free (file_name_2);
@@ -589,16 +566,11 @@ diff_execute (DiffDialog *dialog)
 		gedit_debug (DEBUG_PLUGINS, "file_name_2: %s", file_name_2);
 		g_free (sn);
 		
-		uri = eel_make_uri_canonical (file_name_2);
-		g_return_val_if_fail (uri != NULL, FALSE);
-
-		if (!gedit_document_save_a_copy_as (document, uri, NULL))
+		if (!gedit_document_save_a_copy_as (document, file_name_2, NULL))
 		{
 			g_free (file_name_2);
 			file_name_2 = NULL;
 		}
-
-		g_free (uri);
 	}
 
 	if (file_name_1 == NULL || file_name_2 == NULL)
@@ -800,9 +772,9 @@ configure_real (GtkWindow *parent)
 	
 	gedit_debug (DEBUG_PLUGINS, "");
 	
-	temp = gedit_plugin_locate_program (DIFF_PROGRAM_NAME,
-					    PLUGIN_NAME, 
-					    parent);
+	temp = gedit_plugin_program_location_dialog (DIFF_PROGRAM_NAME, 
+					      	     PLUGIN_NAME, 
+					      	     parent);
 
 	if (temp != NULL)
 	{
