@@ -27,13 +27,9 @@
  * See the ChangeLog files for a list of changes. 
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <gtk/gtk.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-help.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <string.h>
@@ -44,8 +40,6 @@
 #include <gedit-debug.h>
 #include <gedit2.h>
 #include <gedit-document.h>
-#include <gedit-utils.h>
-#include <gedit-menus.h>
 
 enum
 {
@@ -87,25 +81,8 @@ window_destroyed (GtkObject *obj,  void **window_pointer)
 
 	if (window_pointer != NULL)
 	{
-		GList *top_windows;
-        	gedit_debug (DEBUG_PLUGINS, "");
-
-        	top_windows = gedit_get_top_windows ();
-
-        	while (top_windows)
-        	{
-			BonoboUIComponent *ui_component;
-			
-			ui_component = gedit_get_ui_component_from_window (
-					BONOBO_WINDOW (top_windows->data));
-			
-			gedit_menus_set_verb_state (ui_component, "/commands/" MENU_ITEM_NAME, 0);
-
-			top_windows = g_list_next (top_windows);
-		}
-
 		g_free (*window_pointer);
-		*window_pointer = NULL;	
+		*window_pointer = NULL;
 	}	
 }
 
@@ -151,7 +128,7 @@ void taglist_window_show ()
 
 	gtk_tooltips_set_tip (gtk_tooltips_new (),
 			GTK_COMBO (tag_list_window->tag_groups_combo)->entry,
-			_("Select the group of tags you want to use"),
+			_("Select the group of tab you want to use."),
 			NULL);
 	
 	gtk_editable_set_editable (GTK_EDITABLE (
@@ -171,20 +148,11 @@ void taglist_window_show ()
 
 	/* Create tree view */
 	tag_list_window->tags_list = gtk_tree_view_new ();
-
-	gedit_utils_set_atk_name_description (tag_list_window->tag_groups_combo, 
-							_("Tag Groups Combo"), NULL);
-	gedit_utils_set_atk_name_description (tag_list_window->tags_list, 
-							_("Tags Name List"), NULL);
-	gedit_utils_set_atk_relation (tag_list_window->tag_groups_combo, tag_list_window->tags_list, 
-							ATK_RELATION_CONTROLLER_FOR);
-	gedit_utils_set_atk_relation (tag_list_window->tags_list, tag_list_window->tag_groups_combo, 
-							ATK_RELATION_CONTROLLED_BY);
 	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tag_list_window->tags_list), TRUE);
 
 	gtk_tooltips_set_tip (gtk_tooltips_new (),
 			tag_list_window->tags_list,
-			_("Double-click on a tag to insert it in the current document"),
+			_("Double-click on a tag to insert it in the current document."),
 			NULL);
 
 	g_signal_connect_after (G_OBJECT (tag_list_window->tags_list), "row_activated",
@@ -225,15 +193,6 @@ void taglist_window_show ()
 
 }
 
-void 
-taglist_window_close ()
-{
-	gedit_debug (DEBUG_PLUGINS, "");
-
-	if (tag_list_window != NULL)
-		gtk_widget_destroy (GTK_WIDGET (tag_list_window->window));
-}
-
 static void
 populate_tag_groups_combo (void)
 {
@@ -327,8 +286,6 @@ populate_tags_list (void)
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (tag_list_window->tags_list), 
 			         model);
-	
-	g_object_unref (G_OBJECT (model));
 }
 
 static GtkTreeModel*
@@ -352,7 +309,7 @@ create_model (void)
 		const gchar* tag_name;
 
 		tag_name = ((Tag*)list->data)->name;
-
+		
 		gedit_debug (DEBUG_PLUGINS, "%d : %s", i, tag_name);
 		
 		gtk_list_store_append (store, &iter);
@@ -364,7 +321,7 @@ create_model (void)
 
 		list = g_list_next (list);
 	}
-	
+
 	gedit_debug (DEBUG_PLUGINS, "Rows: %d ", 
 			gtk_tree_model_iter_n_children (GTK_TREE_MODEL (store), NULL));
 	
@@ -405,7 +362,7 @@ tag_list_key_press_event_cb (GtkTreeView *tag_list, GdkEventKey *event)
 		GtkTreeIter iter;
 		gint index;
 
-		gedit_debug (DEBUG_PLUGINS, "RETURN Pressed");
+		gedit_debug (DEBUG_PLUGINS, "");
 
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (tag_list_window->tags_list));
 		g_return_val_if_fail (model != NULL, FALSE);
@@ -422,8 +379,6 @@ tag_list_key_press_event_cb (GtkTreeView *tag_list, GdkEventKey *event)
 			insert_tag ((Tag*)g_list_nth_data (tag_list_window->selected_tag_group->tags, index),
 				    event->state & GDK_CONTROL_MASK);
 		}
-
-		return FALSE;
 	}
 
 	return FALSE;
@@ -472,28 +427,10 @@ insert_tag (Tag *tag, gboolean focus_to_document)
 static gboolean 
 tag_list_window_key_press_event_cb (GtkTreeView *tag_list, GdkEventKey *event)
 {
-	if ((event->keyval == 'w') && (event->state & GDK_CONTROL_MASK))
+	if (event->keyval == GDK_Escape)
 	{
-		taglist_window_close ();
+		gtk_widget_destroy (GTK_WIDGET (tag_list_window->window));
 		return TRUE;
-	}
-
-	if (event->keyval == GDK_F1)
-	{
-		GError *error = NULL;
-
-		gedit_debug (DEBUG_PLUGINS, "F1 Pressed");
-
-		gnome_help_display ("gedit.xml", "gedit-use-plugins", &error);
-	
-		if (error != NULL)
-		{
-			g_warning (error->message);
-	
-			g_error_free (error);
-		}
-
-		return FALSE;
 	}	
 
 	return FALSE;
