@@ -27,12 +27,6 @@
  * See the ChangeLog files for a list of changes. 
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <string.h>
-
 #include <libgnome/gnome-i18n.h>
 
 #include <gedit-menus.h>
@@ -43,12 +37,10 @@
 #include "gedit-taglist-plugin-window.h"
 #include "gedit-taglist-plugin-parser.h"
 
-#define MENU_ITEM_LABEL		N_("Tag _List")
-#define MENU_ITEM_PATH		"/menu/View/ViewOps/"
-/*
+#define MENU_ITEM_LABEL		N_("_Show tag list")
+#define MENU_ITEM_PATH		"/menu/Tools/ToolsOps/"
 #define MENU_ITEM_NAME		"TagList"	
-*/
-#define MENU_ITEM_TIP		N_("Show the tag list window")
+#define MENU_ITEM_TIP		N_("Show the tag list window.")
 
 G_MODULE_EXPORT GeditPluginState update_ui (GeditPlugin *plugin, BonoboWindow *window);
 G_MODULE_EXPORT GeditPluginState destroy (GeditPlugin *pd);
@@ -58,25 +50,11 @@ G_MODULE_EXPORT GeditPluginState init (GeditPlugin *pd);
 
 
 static void
-tag_list_cb (BonoboUIComponent           *ui_component,
-	     const char                  *path,
-	     Bonobo_UIComponent_EventType type,
-	     const char                  *state,
-	     gpointer               	  data)
+tag_list_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
-	gboolean s;
-	
-	gedit_debug (DEBUG_PLUGINS, "%s toggled to '%s'", path, state);
-
-	s = (strcmp (state, "1") == 0);
-
-	if (s)
-		taglist_window_show ();
-	else
-		taglist_window_close ();
+	taglist_window_show ();
 }
 
-
 G_MODULE_EXPORT GeditPluginState
 update_ui (GeditPlugin *plugin, BonoboWindow *window)
 {
@@ -109,9 +87,8 @@ activate (GeditPlugin *pd)
 	GList *top_windows;
         gedit_debug (DEBUG_PLUGINS, "");
 
-	if (taglist == NULL)
-		if (create_taglist () == NULL)
-			return PLUGIN_ERROR;
+	if (create_taglist () == NULL)
+		return PLUGIN_ERROR;
 	
         top_windows = gedit_get_top_windows ();
         g_return_val_if_fail (top_windows != NULL, PLUGIN_ERROR);
@@ -120,10 +97,10 @@ activate (GeditPlugin *pd)
         {
 		BonoboUIComponent *ui_component;
 
-		gedit_menus_add_menu_item_toggle (BONOBO_WINDOW (top_windows->data),
+		gedit_menus_add_menu_item (BONOBO_WINDOW (top_windows->data),
 				     MENU_ITEM_PATH, MENU_ITEM_NAME,
-				     MENU_ITEM_LABEL, MENU_ITEM_TIP,
-				     tag_list_cb, NULL);
+				     MENU_ITEM_LABEL, MENU_ITEM_TIP, NULL,
+				     tag_list_cb);
 
 		ui_component = gedit_get_ui_component_from_window (
 					BONOBO_WINDOW (top_windows->data));
@@ -142,9 +119,7 @@ activate (GeditPlugin *pd)
 G_MODULE_EXPORT GeditPluginState
 deactivate (GeditPlugin *pd)
 {
-	gedit_menus_remove_menu_item_toggle_all (MENU_ITEM_PATH, MENU_ITEM_NAME);
-
-	taglist_window_close ();
+	gedit_menus_remove_menu_item_all (MENU_ITEM_PATH, MENU_ITEM_NAME);
 
 	free_taglist ();
 	
@@ -156,7 +131,13 @@ init (GeditPlugin *pd)
 {
 	/* initialize */
 	gedit_debug (DEBUG_PLUGINS, "");
-
+     
+	pd->name = _("Tag list");
+	pd->desc = _("The tag list plugin provides a method to easily insert into a document "
+		     "commonly used tabs/strings without having to type them.");
+	pd->author = "Paolo Maggi <maggi@athena.polito.it>";
+	pd->copyright = _("Copyright (C) 2002 - Paolo Maggi");
+	
 	pd->private_data = NULL;
 		
 	return PLUGIN_OK;
