@@ -321,8 +321,8 @@ get_configure_dialog (GtkWindow* parent)
 					 GTK_RESPONSE_OK);
 
 	
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect (G_OBJECT (dialog->dialog), "destroy",
+			  G_CALLBACK (dialog_destroyed), &dialog);
 	
 	g_object_unref (gui);
 
@@ -353,6 +353,8 @@ time_world_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname
 	gedit_document_insert_text_at_cursor (doc, the_time, -1);
 
 	gedit_document_end_user_action (doc);
+
+	g_free (the_time);
 }
 
 static void
