@@ -4,7 +4,7 @@
  * This file is part of gedit
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
- * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi 
+ * Copyright (C) 2000, 2002 Chema Celorio, Paolo Maggi 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA. * *
+ * Boston, MA 02111-1307, USA. 
  */
  
 /*
@@ -41,31 +41,11 @@
 #include "gedit-recent.h" 
 #include "gedit-prefs.h"
 #include "gedit-file-selector-util.h"
-
-#define USE_BONOBO_FILE_SEL_API	
-
-#ifndef USE_BONOBO_FILE_SEL_API
-static GtkWidget *open_file_selector = NULL;
-static GtkWidget *save_file_selector = NULL;
-
-static gint gedit_file_selector_delete_event_handler (GtkWidget *widget, 
-						      GdkEventAny *event);
-static void gedit_file_selector_cancel_button_clicked_handler (GtkWidget *w,
-						      gpointer data);
-static gint gedit_file_selector_key_press_event_handler (GtkFileSelection *fsel, 
-						   GdkEventKey *event);
-static void gedit_file_open_ok_button_clicked_handler (GtkWidget *widget, 
-						   GeditMDIChild *active_child);
-static void gedit_file_save_as_ok_button_clicked_handler (GtkWidget *widget, 
-							GeditMDIChild *child);
-static GSList*  gedit_file_selector_get_filenames (GtkFileSelection *file_selector);
-static gboolean gedit_file_open_is_dir (GtkFileSelection *file_selector);
-#endif
+#include "gedit-plugins-engine.h"
 
 static gboolean gedit_file_open_real (const gchar* file_name, GeditMDIChild* child);
 static gboolean gedit_file_save_as_real (const gchar* file_name, GeditMDIChild *child);
 
-
 void 
 gedit_file_new (void)
 {
@@ -119,233 +99,9 @@ gedit_file_close (GtkWidget *view)
 		gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 }
 
-#ifndef USE_BONOBO_FILE_SEL_API
-
-static gint
-gedit_file_selector_delete_event_handler (GtkWidget *widget, GdkEventAny *event)
-{
-	gedit_debug (DEBUG_FILE, "");
-
-	gtk_widget_hide (widget);
-	
-	gtk_main_quit ();
-	
-	return TRUE;
-}
- 
-static void
-gedit_file_selector_cancel_button_clicked_handler (GtkWidget *w, gpointer data)
-{
-	gedit_debug (DEBUG_FILE, "");
-	
-	gtk_widget_hide (data);
-
-	gtk_main_quit();
-}
-
-static gint
-gedit_file_selector_key_press_event_handler (GtkFileSelection *fsel, GdkEventKey *event)
-{
-	if (event->keyval == GDK_Escape) {
-		gtk_button_clicked (GTK_BUTTON (fsel->cancel_button));
-		return 1;
-	} else
-		return 0;
-}
-
-static GSList *
-gedit_file_selector_get_filenames (GtkFileSelection *file_selector)
-{
-	GtkCListRow *row;
-	GtkCList *rows;
-	GSList *files = NULL;
-	GList *list;
-	gchar *file;
-	gint row_num = 0;
-
-	g_return_val_if_fail (GTK_IS_FILE_SELECTION (file_selector), NULL);
-
-	rows = GTK_CLIST (file_selector->file_list);
-	list = rows->row_list;
-	for (; list != NULL; list = list->next) 
-	{
-		row = list->data;
-		gtk_clist_get_text (rows, row_num, 0, &file);
-		if (row->state == GTK_STATE_SELECTED)
-			files = g_slist_prepend (files, g_strdup(file));
-		row_num++;
-	}
-						 
-	return files;
-}
-
-
-static gboolean
-gedit_file_open_is_dir (GtkFileSelection *file_selector)
-{
-	static const gchar *selected_file;
-	gchar *directory;
-	gint length;
-
-	selected_file = gtk_file_selection_get_filename (file_selector);
-
-	if (!g_file_test (selected_file, G_FILE_TEST_IS_DIR))
-		return FALSE;
-	
-	length = strlen (selected_file);
-
-	if (selected_file [length-1] == '/')
-		directory = g_strdup (selected_file);
-	else
-		directory = g_strdup_printf ("%s%c", selected_file, '/');
-
-	gtk_file_selection_set_filename (file_selector, directory);
-	gtk_entry_set_text (GTK_ENTRY(file_selector->selection_entry), "");
-
-	g_free (directory);
-	
-	return TRUE;
-}
-
-static void
-gedit_file_open_ok_button_clicked_handler (GtkWidget *widget, GeditMDIChild *active_child)
-{
-	GtkFileSelection *file_selector;
-	const gchar * file_name;
-	gchar * full_path;
-	gchar * directory;
-	GSList *files;
-	gint loaded_file = 0;
-
-	gedit_debug (DEBUG_FILE, "");
-
-	g_return_if_fail (GTK_IS_FILE_SELECTION (open_file_selector));
-	file_selector = GTK_FILE_SELECTION (open_file_selector);
-
-	if (gedit_file_open_is_dir (file_selector))
-		return;
-
-	file_name = gtk_file_selection_get_filename (file_selector);
-	directory = g_dirname (file_name);
-
-	files = gedit_file_selector_get_filenames (file_selector);
-
-	if (files == NULL) 
-	{
-		if (gedit_file_open_real (file_name, active_child))
-			gedit_utils_flash_va (_("Loaded file '%s'"), file_name);
-		
-		gedit_debug (DEBUG_FILE, "File: %s", file_name);
-	} 
-	else	     	
-	{
-		gint l;
-
-		l = g_slist_length (files);
-		
-		if (l > 1)
-			gedit_utils_flash_va (_("Loading %d file..."), l);
-
-		for (; files != NULL; files = files->next) 
-		{
-			full_path = g_concat_dir_and_file (directory, files->data);
-			
-			if (gedit_file_open_real (full_path, active_child))
-				++loaded_files;
-			
-			gedit_debug (DEBUG_FILE, "File: %s", full_path);
-
-			g_free (files->data);
-			g_free (full_path);
-		}
-	}
-
-	if (loaded_files > 1)
-		gedit_utils_flash_va (_("Loaded %i files"), loaded_files);
-
-	g_free (directory);
-	g_slist_free (files);
-	
-	gtk_widget_hide (GTK_WIDGET (file_selector));
-
-	gtk_main_quit ();
-		
-	return;
-}
-#endif
-
 void
 gedit_file_open (GeditMDIChild *active_child)
 {
-#ifndef USE_BONOBO_FILE_SEL_API
-
-	gint ok_signal_id = 0;
-	
-	gedit_debug (DEBUG_FILE, "");
-
-	g_return_if_fail (!(open_file_selector && GTK_WIDGET_VISIBLE (open_file_selector)));
-
-	if (open_file_selector == NULL)
-	{
-		open_file_selector = gtk_file_selection_new (NULL);
-		
-		gtk_signal_connect (GTK_OBJECT (open_file_selector),
-				    "delete_event",
-				    GTK_SIGNAL_FUNC (gedit_file_selector_delete_event_handler),
-				    open_file_selector);
-		gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (open_file_selector)->cancel_button),
-				    "clicked",
-				    GTK_SIGNAL_FUNC (gedit_file_selector_cancel_button_clicked_handler),
-				    open_file_selector);
-		gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (open_file_selector)),
-				    "key_press_event",
-				    GTK_SIGNAL_FUNC (gedit_file_selector_key_press_event_handler),
-				    NULL);
-		gtk_clist_set_selection_mode (
-			GTK_CLIST(GTK_FILE_SELECTION (open_file_selector)->file_list),
-			GTK_SELECTION_EXTENDED);
-
-		gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (open_file_selector));
-	}
-	else
-	{
-		GtkFileSelection *file_selector;
-
-		g_return_if_fail (GTK_IS_FILE_SELECTION (open_file_selector));
-
-		/* Clear the selection & file from the last open */
-		file_selector = GTK_FILE_SELECTION (open_file_selector);
-		gtk_clist_unselect_all (GTK_CLIST (file_selector->file_list));
-		gtk_entry_set_text (GTK_ENTRY (file_selector->selection_entry), "");
-	}
-
-	ok_signal_id = gtk_signal_connect (
-			    GTK_OBJECT (GTK_FILE_SELECTION (open_file_selector)->ok_button),
-			    "clicked",
-			    GTK_SIGNAL_FUNC (gedit_file_open_ok_button_clicked_handler),
-			    active_child);
-
-
-	/* FIXME: is this right? */
-	gtk_window_set_transient_for (GTK_WINDOW (open_file_selector), 
-			              GTK_WINDOW (bonobo_mdi_get_active_window (BONOBO_MDI (gedit_mdi))));
-
-	gtk_window_set_modal (GTK_WINDOW (open_file_selector), TRUE);
-	gtk_window_set_title (GTK_WINDOW (open_file_selector), _("Open File ..."));
-
-	if (!GTK_WIDGET_VISIBLE (open_file_selector))
-	{
-		gtk_window_position (GTK_WINDOW (open_file_selector), GTK_WIN_POS_MOUSE);
-		gtk_widget_show (open_file_selector);
-	}
-
-	gtk_main ();
-
-	gtk_signal_disconnect (GTK_OBJECT (GTK_FILE_SELECTION (open_file_selector)->ok_button),
-			ok_signal_id);
-
-	return;
-#else
 	gchar** files;
 	
 	gedit_debug (DEBUG_FILE, "");
@@ -370,7 +126,6 @@ gedit_file_open (GeditMDIChild *active_child)
 
 		g_strfreev (files);
 	}
-#endif	
 }
 
 static gboolean
@@ -477,10 +232,10 @@ gedit_file_open_real (const gchar* file_name, GeditMDIChild* active_child)
 
 	gedit_recent_add (uri);
 	gedit_recent_update_all_windows (BONOBO_MDI (gedit_mdi)); 
-	
+
 	g_free (uri);
 
-	gedit_debug (DEBUG_FILE, "END");
+	gedit_debug (DEBUG_FILE, "END: %s\n", file_name);
 
 	return TRUE;
 }
@@ -591,77 +346,6 @@ gedit_file_save (GeditMDIChild* child)
 gboolean
 gedit_file_save_as (GeditMDIChild *child)
 {
-#ifndef USE_BONOBO_FILE_SEL_API
-
-	gint ok_signal_id = 0;
-	GeditDocument* doc = NULL;
-	gchar *fname = NULL;
-	GtkWidget *view = NULL;
-	
-	gedit_debug (DEBUG_FILE, "");
-
-	g_return_val_if_fail (child != NULL, FALSE);
-
-	doc = child->document;
-	g_return_val_if_fail (doc != NULL, FALSE);
-
-	g_return_val_if_fail (!(save_file_selector && GTK_WIDGET_VISIBLE (save_file_selector)), FALSE);
-
-	view = GTK_WIDGET (g_list_nth_data (
-				bonobo_mdi_child_get_views (BONOBO_MDI_CHILD (child)), 0));
-	if (view != NULL)
-		bonobo_mdi_set_active_view (BONOBO_MDI (gedit_mdi), view);
-
-	if (save_file_selector == NULL)
-	{
-		save_file_selector = gtk_file_selection_new (NULL);
-		
-		gtk_signal_connect (GTK_OBJECT (save_file_selector),
-				    "delete_event",
-				    GTK_SIGNAL_FUNC (gedit_file_selector_delete_event_handler),
-				    save_file_selector);
-		gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (save_file_selector)->cancel_button),
-				    "clicked",
-				    GTK_SIGNAL_FUNC (gedit_file_selector_cancel_button_clicked_handler),
-				    save_file_selector);
-		gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION(save_file_selector)),
-				    "key_press_event",
-				    GTK_SIGNAL_FUNC (gedit_file_selector_key_press_event_handler),
-				    NULL);
-		
-		gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (save_file_selector));
-	}
-	
-	ok_signal_id = gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION(save_file_selector)->ok_button),
-				    "clicked",
-				    GTK_SIGNAL_FUNC (gedit_file_save_as_ok_button_clicked_handler),
-				    child);
-		
-	fname = gedit_document_get_uri (doc);
-	
-	gtk_file_selection_set_filename (GTK_FILE_SELECTION (save_file_selector), fname);
-	g_free (fname);
-
-	gtk_window_set_transient_for (GTK_WINDOW (save_file_selector), 
-				      GTK_WINDOW (bonobo_mdi_get_active_window (BONOBO_MDI (gedit_mdi))));
-
-	gtk_window_set_modal (GTK_WINDOW (save_file_selector), TRUE);
-	gtk_window_set_title (GTK_WINDOW (save_file_selector), _("Save As..."));
-
-	if (!GTK_WIDGET_VISIBLE (save_file_selector))
-	{
-		gtk_window_position (GTK_WINDOW (save_file_selector), GTK_WIN_POS_MOUSE);
-		gtk_widget_show(save_file_selector);
-	}
-
-	gtk_main ();
-
-	gtk_signal_disconnect (GTK_OBJECT(GTK_FILE_SELECTION(save_file_selector)->ok_button),
-			ok_signal_id);
-
-	return !gedit_document_get_modified (child->document);
-
-#else		
 	gchar* file;
 	gboolean ret = FALSE;
 	GeditDocument *doc;
@@ -701,7 +385,6 @@ gedit_file_save_as (GeditMDIChild *child)
 	}
 
 	return ret;
-#endif
 }
 
 static gboolean
@@ -782,74 +465,6 @@ gedit_file_save_as_real (const gchar* file_name, GeditMDIChild *child)
 	}
 }
 
-#ifndef USE_BONOBO_FILE_SEL_API
-
-static void
-gedit_file_save_as_ok_button_clicked_handler (GtkWidget *widget, GeditMDIChild *child)
-{
-	GtkFileSelection *file_selector;
-	const gchar *file_name;
-	gboolean ret;
-
-	gedit_debug (DEBUG_FILE, "");
-
-	g_return_if_fail (child != NULL);
-
-	g_return_if_fail (GTK_IS_FILE_SELECTION (save_file_selector));
-	file_selector = GTK_FILE_SELECTION (save_file_selector);
-
-	if (gedit_file_open_is_dir (file_selector))
-		return;
-
-	file_name = gtk_file_selection_get_filename (file_selector);
-	g_return_if_fail (file_name != NULL);
-	
-	if (g_file_test (file_name, G_FILE_TEST_EXISTS))
-	{
-		GtkWidget *msgbox;
-		gint ret;
-		
-		msgbox = gtk_message_dialog_new (GTK_WINDOW (file_selector),
-				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_QUESTION,
-				GTK_BUTTONS_CANCEL,
-				_("A file named ``%s'' already exists in this location. Do you want to "
-				  "replace it with the one you are saving?"), 
-				file_name);
-
-		gtk_dialog_add_button (GTK_DIALOG (msgbox),
-                             _("_Replace"),
-                             GTK_RESPONSE_YES);
-
-		gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_CANCEL);
-
-		gtk_window_set_resizable (GTK_WINDOW (msgbox), FALSE);
-
-		ret = gtk_dialog_run (GTK_DIALOG (msgbox));
-		
-		gtk_widget_destroy (msgbox);
-
-		if (ret != GTK_RESPONSE_YES)
-			return;
-	}
-
-	gtk_widget_hide (GTK_WIDGET (file_selector));
-
-	gedit_utils_flash_va (_("Saving file '%s' ..."), file_name);
-		
-	ret = gedit_file_save_as_real (file_name, child);
-		
-	if (ret)
-		gedit_utils_flash_va (_("File '%s' saved."), file_name);
-	else
-		gedit_utils_flash_va (_("The document has not been saved."));
-
-	gtk_main_quit ();
-	
-	return;
-}
-
-#endif
 
 gboolean
 gedit_file_close_all (void)
@@ -877,9 +492,12 @@ gedit_file_exit (void)
 	
 	/* We need to disconnect the signal because mdi "destroy" event
 	   is connected to gedit_file_exit ( i.e. this function ). */
-	gtk_signal_disconnect_by_func (GTK_OBJECT (gedit_mdi),
-			    GTK_SIGNAL_FUNC (gedit_file_exit), NULL);
-		
+	g_signal_handlers_disconnect_by_func (
+			G_OBJECT (gedit_mdi),
+			G_CALLBACK (gedit_file_exit), NULL);
+	
+	gedit_plugins_engine_save_settings ();
+	
 	gedit_prefs_save_settings ();
 
 	gedit_recent_history_save ();
@@ -896,7 +514,7 @@ gedit_file_exit (void)
 void
 gedit_file_save_all (void)
 {
-	gint i = 0;
+	guint i = 0;
 	GeditMDIChild* child;
 	GtkWidget* view;
 
@@ -1081,14 +699,26 @@ gedit_file_open_uri_list (GList* uri_list, gint line)
 }
 
 gboolean 
-gedit_file_open_recent (GeditMDIChild *child, gchar* uri)
+gedit_file_open_recent (GeditMDIChild *child, const gchar* uri)
 {
 	gboolean ret;
-	gedit_debug (DEBUG_FILE, "");
+	gchar *temp_uri;
+
+	gedit_debug (DEBUG_FILE, "Open : %s", uri);
+
+	/* we need to do this to avoid gedit_recent_add() freeing our uri */
+	temp_uri = g_strdup (uri);
 	
-	ret = gedit_file_open_real (uri, child);	
+	ret = gedit_file_open_real (temp_uri, child);
+
 	if (ret)
-		gedit_utils_flash_va (_("Loaded file '%s'"), uri);
+	{
+		gchar* t = gnome_vfs_x_format_uri_for_display (temp_uri);
+		gedit_utils_flash_va (_("Loaded file %s"), t);
+		g_free (t);
+	}
+
+	g_free (temp_uri);
 
 	gedit_debug (DEBUG_FILE, "END");
 
